*Comandi da admin*

\- un post sarà pubblicato o rifiutato quando i rispettivi voti supereranno la soglia stabilita
\- fino a che un post non è stato pubblicato o rifiutato, l'utente che lo ha proposto non potrà proporre altri post, per evitare spam indesiderati
\- è possibile mandare un messaggio all'utente che ha creato un post rispondendo con "/reply <messaggio\>" ad un suo post\. Può essere utile per spiegare perché il suo post non è stato approvato, prima di rifiutare il post in questione
\- per bannare un utente, rispondere al post che ha causato il ban con "/ban"
\- per sbannare un utente, utilizzare il comando "/sban <id utente\>"
\- utilizzare il comando "/clean\_pending" per rifiutare automaticamente tutti i post abbastanza vecchi
\- utilizzare il comando "/purge" per eliminare dal database tutti i post e i rispettivi voti di cui si è perso il messaggio
